"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("dustjs-helpers");
const dust = require("dustjs-linkedin");
/**
 * Render a template with the given template loader and dust template engine.
 */
class DustTemplateRenderer {
    constructor(templateLoader, opts) {
        const options = opts || {};
        const isDev = options.isDev === undefined ? process.env.NODE_ENV !== "production" : options.isDev;
        if (isDev) {
            dust.debugLevel = "INFO";
        }
        this._templateLoader = templateLoader;
        this._extension = options.extension || "dust";
        dust.onLoad = (templateName, params, callback) => {
            templateName = this.addExtension(templateName);
            this._templateLoader.load(templateName, (err, template) => {
                if (err) {
                    callback(err, null);
                }
                else {
                    callback(null, template.content);
                }
            });
        };
    }
    render(fileName, params, engineConfig, callback) {
        fileName = this.addExtension(fileName);
        this._templateLoader.load(fileName, (err, template) => {
            if (err) {
                callback(err, null);
            }
            else {
                try {
                    const compiled = dust.compile(template.content, template.fileName);
                    dust.loadSource(compiled);
                    dust.render(template.fileName, params, callback);
                }
                catch (e) {
                    callback(e, null);
                }
            }
        });
    }
    addExtension(fileName) {
        if (!fileName.endsWith(this._extension)) {
            return fileName + "." + this._extension;
        }
        else {
            return fileName;
        }
    }
}
exports.default = DustTemplateRenderer;
//# sourceMappingURL=DustTemplateRenderer.js.map